@@ -3,6 +3,7 @@ import logging
 import numpy
 
 from openfisca_core import periods
+from openfisca_core.periods import Period
 
 log = logging.getLogger(__name__)
 
@@ -27,7 +28,7 @@ def set_input_dispatch_by_period(holder, period, array):
     after_instant = period.start.offset(period_size, period_unit)
 
     # Cache the input data, skipping the existing cached months
-    sub_period = period.start.period(cached_period_unit)
+    sub_period = Period((cached_period_unit, period.start, 1))
     while sub_period.start < after_instant:
         existing_array = holder.get_array(sub_period)
         if existing_array is None:
@@ -60,7 +61,7 @@ def set_input_divide_by_period(holder, period, array):
 
     # Count the number of elementary periods to change, and the difference with what is already known.
     remaining_array = array.copy()
-    sub_period = period.start.period(cached_period_unit)
+    sub_period = Period((cached_period_unit, period.start, 1))
     sub_periods_count = 0
     while sub_period.start < after_instant:
         existing_array = holder.get_array(sub_period)
@@ -73,7 +74,7 @@ def set_input_divide_by_period(holder, period, array):
     # Cache the input data
     if sub_periods_count > 0:
         divided_array = remaining_array / sub_periods_count
-        sub_period = period.start.period(cached_period_unit)
+        sub_period = Period((cached_period_unit, period.start, 1))
         while sub_period.start < after_instant:
             if holder.get_array(sub_period) is None:
                 holder._set(sub_period, divided_array)
