@@ -6,4 +6,4 @@ class ParameterScaleBracket(ParameterNode):
     A parameter scale bracket.
     """
 
-    _allowed_keys = set(['amount', 'threshold', 'rate', 'average_rate', 'base'])
+    _allowed_keys = set(['amount', 'threshold', 'rate', 'average_rate'])
